@@ -24,7 +24,7 @@ import torch
 from PIL import Image
 
 import requests
-from huggingface_hub import cached_download, hf_hub_url
+from huggingface_hub import hf_hub_download
 from adapter_transformers import (
     SegformerConfig,
     SegformerFeatureExtractor,
@@ -151,7 +151,7 @@ def convert_segformer_checkpoint(model_name, checkpoint_path, pytorch_dump_folde
         raise ValueError(f"Model {model_name} not supported")
 
     # set config attributes
-    id2label = json.load(open(cached_download(hf_hub_url(repo_id, filename)), "r"))
+    id2label = json.load(open(hf_hub_download(repo_id, filename), "r"))
     id2label = {int(k): v for k, v in id2label.items()}
     config.id2label = id2label
     config.label2id = {v: k for k, v in id2label.items()}
