@@ -304,8 +304,9 @@ class AdamW(Optimizer):
     ):
         if not no_deprecation_warning:
             warnings.warn(
-                "This implementation of AdamW is deprecated and will be removed in a future version. Use the"
-                " PyTorch implementation torch.optim.AdamW instead, or set `no_deprecation_warning=True` to disable this warning",
+                "This implementation of AdamW is deprecated and will be removed in a future version. Use the PyTorch"
+                " implementation torch.optim.AdamW instead, or set `no_deprecation_warning=True` to disable this"
+                " warning",
                 FutureWarning,
             )
         require_version("torch>=1.5.0")  # add_ with alpha
